## 电影日度票房

接口：bo_daily

描述：获取电影日度票房

数据更新：当日更新上一日数据

数据历史： 数据从2018年9月开始，更多历史数据正在补充

数据权限：用户需要至少500积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 （格式YYYYMMDD） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| name | str | Y | 影片名称 |
| avg_price | float | Y | 平均票价 |
| day_amount | float | Y | 当日票房（万） |
| total | float | Y | 累计票房（万） |
| list_day | int | Y | 上映天数 |
| p_pc | int | Y | 场均人次 |
| wom_index | float | Y | 口碑指数 |
| up_ratio | float | Y | 环比变化 （%） |
| rank | int | Y | 排名 |

接口使用

```python
pro = ts.pro_api()
#或者
#pro = ts.pro_api('your token')

df = pro.bo_daily(date='20181014')
```

数据示例

```python
date      name  avg_price  day_amount    total  list_day  p_pc  \
0  20181014   无双       37.0      4720.0  93611.0        15    16   
```